@@ -1,11 +1,10 @@
+import sys
 import inspect
-from django.utils.encoding import python_2_unicode_compatible
-from enum import Enum as BaseEnum, EnumMeta as BaseEnumMeta, _EnumDict
+from enum import _EnumDict
+from enum import Enum as BaseEnum
+from enum import EnumMeta as BaseEnumMeta
 
-try:
-    from django.utils.encoding import force_text
-except ImportError:
-    from django.utils.encoding import force_unicode as force_text
+from django.utils.encoding import force_str
 
 
 class EnumMeta(BaseEnumMeta):
@@ -17,6 +16,9 @@ class EnumMeta(BaseEnumMeta):
             if hasattr(attrs, '_member_names'):
                 attrs._member_names.remove('Labels')
 
+        if sys.version_info >= (3, 9, 2):
+            attrs._cls_name = name
+
         obj = BaseEnumMeta.__new__(mcs, name, bases, attrs)
         for m in obj:
             try:
@@ -27,7 +29,6 @@ class EnumMeta(BaseEnumMeta):
         return obj
 
 
-@python_2_unicode_compatible
 class Enum(EnumMeta('Enum', (BaseEnum,), _EnumDict())):
     @classmethod
     def choices(cls):
@@ -41,4 +42,9 @@ class Enum(EnumMeta('Enum', (BaseEnum,), _EnumDict())):
         """
         Show our label when Django uses the Enum for displaying in a view
         """
-        return force_text(self.label)
+        return force_str(self.label)
+
+
+class IntEnum(int, Enum):
+    def __str__(self):  # See Enum.__str__
+        return force_str(self.label)
